import org.activemq.openwire.tool.OpenWireScript

/**
 * Generates the Java marshalling code for the Open Wire Format
 *
 * @version $Revision: 1.1.1.1 $
 */
class GenerateJavaMarshalling extends OpenWireScript {

    Object run() {
        def destDir = new File("src/java/org/activemq/transport/openwire/io")
        destDir.mkdirs()

        def file = new File(destDir, "OpenWireFormat.java")
        def messageClasses = classes.findAll { isMessageType(it) }

        file.withWriter { out |
            out << """/**
 * OpenWireFormat code
 *
 *
 * NOTE!: This file is autogenerated - do not modify!
 *        if you need to make a change, please see the Groovy scripts in the
 *        activemq-openwire module
 */

package org.activemq.transport.openwire.io;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import org.activemq.message.*;
import org.activemq.io.*;
import org.activemq.io.impl.*;
import org.activemq.transport.openwire.OpenWireFormatSupport;

/**
 * AUTOGENERATED WireFormat OpenWire
 *
 * @version \$Revision: 1.1 \$
 */
public class OpenWireFormat extends OpenWireFormatSupport {

    private Map marshallersByTypeName = new HashMap();

"""

            for (jclass in messageClasses) {

                println "Processing $jclass.qualifiedName"

                out << """
    protected transient AbstractPacketMarshaller ${decapitalize(jclass.simpleName)}Marshaller = new ${jclass.simpleName}Marshaller();
"""
            }
            out << """
    public OpenWireFormat() {
"""
            for (jclass in messageClasses) {
                out << """
    marshallersByTypeName.put("${jclass.qualifiedName}", ${decapitalize(jclass.simpleName)}Marshaller);
"""
            }
            out << """
    }

    public Packet readPacket(int firstByte, DataInput dataIn) throws IOException {
        switch (firstByte) {
"""
            for (jclass in messageClasses) {
            out << """
            case ${getEnum(jclass)} :
                return readPacket(dataIn, ${decapitalize(jclass.simpleName)}Marshaller);

"""
            }
            out << """
        }
        return null;
    }

    protected  AbstractPacketMarshaller getMarshaller(Packet packet) {
        return (AbstractPacketMarshaller) marshallersByTypeName.get(packet.getClass().getName());
    }
}
"""
        }
    }
}